function w = SplineScal( x, j, k, m, a, b )
% SplineScal generates dilated/translated B-spline, B(a^j*x-b*k), of order m on the given
% interval.
%
% Usage:    w = SplineScal( x, j, k, m, a, b 
%
% Inputs:
%   x       a dicretization of the given interval
%   j,k     dilation and translation parameters
%   a       scaling factor
%   b       translation factor
%   m       order of spline (positive integer)
%
% Output:
%   w       dilated/translated B-spline of a given order

% See http://www.ncrg.aston.ac.uk/Projects/BiOrthog/ for more details
switch m
    case 1
        coef=[0 1];
    case 2
        coef=[1 0;-1 2];
    case 3
        coef=[1 0 0;-2 6 -3;1 -6 9]/2;
    case 4
        coef=[1 0 0 0;-3 12 -12 4; 3 -24 60 -44;-1 12 -48 64]/6;
    otherwise
        %error('Wrong order of B-splines');
        [dummy,coef]=SymSpline(m);
end

nods=0:m;             % nodes of scaling function
pocet=length(nods);       %POCET is the number of nods
x=a^j*x-b*k;
w=[];
w =[w 0*(x(x<nods(1)))];
for i=2:pocet
    z=x((x>=nods(i-1)) & (x<nods(i)));
    w=[w polyval(coef(i-1,:),z)];
end
w=[w 0*(x(x>=nods(pocet)))];

%normalization
%nor=norm(w);
%if nor~=0; w=w/nor;end;
%w=w*a^(-j/2);


%Copyright (C) 2006 Miroslav ANDRLE and Laura REBOLLO-NEIRA
%
%This program is free software; you can redistribute it and/or modify it under the terms 
%of the GNU General Public License as published by the Free Software Foundation; either 
%version 2 of the License, or (at your option) any later version.
%
%This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
%without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with this program;
%if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
%Boston, MA  02110-1301, USA.
