% exa_OOMPKSwaps improves upon the OOMP approximation  by k swappings 
%
% Creates a cardinal B-spline dictionary and a the signal f as a random superposition of
% 95 splines. Calls OOMP_KSWAPS (which uses KSwapping) to improve the OOMP approximation
% by k swappings, untill tols=1e-9*norm(f) is reached.

sp=[0 8];m=4;b1=2^(-3) ;b2=2^(-4); k=8;L=(sp(2)-sp(1))/b2*k+1;
type='ESEP';x=linspace(sp(1),sp(2),L);
D=DictSpline(m,L,sp,b1,b2,type);
N=size(D,2);
%===========================================================================
% generates the signal f as a random superposition of Num=95 B-splines
%===========================================================================
Num=95; randn('state',13);amp=randn(Num,1);rand('state',19);ip=randperm(N);
f=D(:,ip(1:Num))*amp;
%===========================================================================
% call OOMP_KSWAPS (which uses KSWAPPING) to improve the OOMP approximation 
% of f by k swappings, untill tols=1e-9*norm(f) is reached
%============================================================================
err=1e-5*norm(f); No=115;ind=[];swi=1;sws=[];tols=1e-9*norm(f);
%
[re,resid,DS,Di,beta,C,Q]=OOMPKSwaps(f',D,err,No,ind,swi,sws,tols);
%
%checks if the all the atoms in the decomposition of the given f have been chosen
di=size(beta,2);
ii=ismember(ip(1:Num),Di(1:di));
if ii==1 fprintf('\n all the atoms have been picked \n');
      else 
        fprintf('\n some atoms have NOT been picked \n'); 
end
