% exa_image_approximation approximating an image using OMP
%
% Example of using the OMP algorithm to approximate the image of Lena using a dictionary
% comprised from a deiscrete cosine redundancy 2 dictionary and hat dictionaries of
% support 1, 3 and 5.

% See   http://www.ncrg.aston.ac.uk/Projects/HNLApprox/
%       http://www.nonlinear-approx.info/

% Load the image
imageFile = 'lena.tiff';
mImage = double( imread(imageFile) );
[ x y ] = size( mImage );
blockWidth = 16;
% Set up the dictionaries
mCosineDictionary = DCos( blockWidth, (2*blockWidth) - 1 , 2); % Generate cosine dictionary redundancy 2
nCosineAtoms = size( mCosineDictionary, 2 );
hats = 1:2:5; % Choose support for the hat dictionaries
mHatDictionaries = GenerateHats( hats, blockWidth, 1 ); % Generate hat dictionaries
nHatAtoms = size( mHatDictionaries, 2 );
mDictionaries1D = mCosineDictionary;
mDictionaries1D( :, nCosineAtoms+1:nCosineAtoms+nHatAtoms ) = mHatDictionaries;
mUniqueDictionary = RemoveDependantAtoms( mDictionaries1D, 1e-10 ); % Remove any similar atoms
mNormalisedDictionary = NormDict( mUniqueDictionary );
mDictionaries2D = kron( mNormalisedDictionary, mNormalisedDictionary );
algorithm = 'OMP';
tolerance = 40;
[ mImageApprox, mNCn ] = ImageApproximation( mImage, mDictionaries2D, algorithm, ...
    tolerance, blockWidth);
psnr = CalcPSNR( mImage, mImageApprox ); % Calculate the error
compressionRatio = (x*y)/sum(mNCn(:)); % Calculate the compression ratio
imshow( uint8(mImage) ); % Display the original image
figure;
imshow( uint8(mImageApprox) ); % Display the approximated image